Package: tweenr
Type: Package
Title: Interpolate Data for Smooth Animations
Version: 2.0.3
Authors@R: 
    c(person(given = "Thomas Lin",
             family = "Pedersen",
             role = c("aut", "cre"),
             email = "thomasp85@gmail.com",
             comment = c(ORCID = "0000-0002-5147-4711")))
Maintainer: Thomas Lin Pedersen <thomasp85@gmail.com>
Description: In order to create smooth animation between states of data,
    tweening is necessary. This package provides a range of functions for
    creating tweened data that can be used as basis for animation. Furthermore 
    it adds a number of vectorized interpolaters for common R data 
    types such as numeric, date and colour.
URL: https://github.com/thomasp85/tweenr
BugReports: https://github.com/thomasp85/tweenr/issues
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 3.2.0)
Imports: farver, magrittr, rlang, vctrs
LinkingTo: cpp11 (>= 0.4.2)
RoxygenNote: 7.2.3
Suggests: testthat, covr
NeedsCompilation: yes
Packaged: 2024-02-26 13:06:33 UTC; thomas
Author: Thomas Lin Pedersen [aut, cre]
    (<https://orcid.org/0000-0002-5147-4711>)
Repository: CRAN
Date/Publication: 2024-02-26 13:50:03 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 14:16:21 UTC; unix
Archs: tweenr.so.dSYM
