# Generated by roxygen2: do not edit by hand

S3method(convert_generator,along_generator)
S3method(convert_generator,component_generator)
S3method(convert_generator,default)
S3method(convert_generator,keyframe_generator)
S3method(get_frame,along_generator)
S3method(get_frame,component_generator)
S3method(get_frame,keyframe_generator)
S3method(get_raw_frames,along_generator)
S3method(get_raw_frames,component_generator)
S3method(get_raw_frames,keyframe_generator)
S3method(vec_tween_class,Date)
S3method(vec_tween_class,POSIXt)
S3method(vec_tween_class,character)
S3method(vec_tween_class,default)
S3method(vec_tween_class,factor)
S3method(vec_tween_class,list)
S3method(vec_tween_class,logical)
S3method(vec_tween_class,numeric)
export("%>%")
export("col_types<-")
export("ease_type<-")
export("frame_times<-")
export("gen_data<-")
export("generator_settings<-")
export("keyframes<-")
export(.complete_states)
export(.get_first_frame)
export(.get_last_frame)
export(.has_frames)
export(.max_id)
export(.with_later_frames)
export(.with_prior_frames)
export(PHASE_LEVELS)
export(add_keyframe)
export(add_pause)
export(close_state)
export(col_classes)
export(col_types)
export(data_frame_to_gen)
export(display_ease)
export(ease_type)
export(frame_times)
export(gen_along)
export(gen_at)
export(gen_components)
export(gen_data)
export(gen_events)
export(gen_keyframe)
export(gen_to_data_frame)
export(generator_settings)
export(get_frame)
export(get_raw_frames)
export(interpolate_custom_at)
export(is_generator)
export(keep_state)
export(keyframes)
export(open_state)
export(prepare_keyframes)
export(tween)
export(tween_along)
export(tween_appear)
export(tween_at)
export(tween_at_t)
export(tween_color)
export(tween_color_t)
export(tween_colour)
export(tween_colour_t)
export(tween_components)
export(tween_constant)
export(tween_constant_t)
export(tween_date)
export(tween_date_t)
export(tween_datetime)
export(tween_datetime_t)
export(tween_elements)
export(tween_events)
export(tween_fill)
export(tween_numeric)
export(tween_numeric_t)
export(tween_state)
export(tween_states)
export(tween_t)
export(vec_tween_class)
importFrom(farver,decode_colour)
importFrom(farver,encode_colour)
importFrom(graphics,plot)
importFrom(magrittr,"%>%")
importFrom(rlang,"%||%")
importFrom(rlang,as_function)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,is_integerish)
importFrom(rlang,quo_is_missing)
importFrom(rlang,quo_is_null)
importFrom(vctrs,vec_cbind)
importFrom(vctrs,vec_rbind)
useDynLib(tweenr, .registration = TRUE)
