# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

numeric_state_interpolator <- function(data, states) {
    .Call('_tweenr_numeric_state_interpolator', PACKAGE = 'tweenr', data, states)
}

colour_state_interpolator <- function(data, states) {
    .Call('_tweenr_colour_state_interpolator', PACKAGE = 'tweenr', data, states)
}

constant_state_interpolator <- function(data, states) {
    .Call('_tweenr_constant_state_interpolator', PACKAGE = 'tweenr', data, states)
}

list_state_interpolator <- function(data, states) {
    .Call('_tweenr_list_state_interpolator', PACKAGE = 'tweenr', data, states)
}

numlist_state_interpolator <- function(data, states) {
    .Call('_tweenr_numlist_state_interpolator', PACKAGE = 'tweenr', data, states)
}

phase_state_interpolator <- function(data, states) {
    .Call('_tweenr_phase_state_interpolator', PACKAGE = 'tweenr', data, states)
}

numeric_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_numeric_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

colour_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_colour_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

constant_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_constant_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

list_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_list_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

numlist_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_numlist_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

phase_element_interpolator <- function(data, group, frame, ease) {
    .Call('_tweenr_phase_element_interpolator', PACKAGE = 'tweenr', data, group, frame, ease)
}

numeric_along_interpolator <- function(data, group, time, history, keep_last, nframes, ease) {
    .Call('_tweenr_numeric_along_interpolator', PACKAGE = 'tweenr', data, group, time, history, keep_last, nframes, ease)
}

colour_along_interpolator <- function(data, group, time, history, keep_last, nframes, ease) {
    .Call('_tweenr_colour_along_interpolator', PACKAGE = 'tweenr', data, group, time, history, keep_last, nframes, ease)
}

constant_along_interpolator <- function(data, group, time, history, keep_last, nframes, ease) {
    .Call('_tweenr_constant_along_interpolator', PACKAGE = 'tweenr', data, group, time, history, keep_last, nframes, ease)
}

list_along_interpolator <- function(data, group, time, history, keep_last, nframes, ease) {
    .Call('_tweenr_list_along_interpolator', PACKAGE = 'tweenr', data, group, time, history, keep_last, nframes, ease)
}

numlist_along_interpolator <- function(data, group, time, history, keep_last, nframes, ease) {
    .Call('_tweenr_numlist_along_interpolator', PACKAGE = 'tweenr', data, group, time, history, keep_last, nframes, ease)
}

phase_along_interpolator <- function(group, time, history, keep_last, nframes) {
    .Call('_tweenr_phase_along_interpolator', PACKAGE = 'tweenr', group, time, history, keep_last, nframes)
}

numeric_at_interpolator <- function(from, to, at, ease) {
    .Call('_tweenr_numeric_at_interpolator', PACKAGE = 'tweenr', from, to, at, ease)
}

colour_at_interpolator <- function(from, to, at, ease) {
    .Call('_tweenr_colour_at_interpolator', PACKAGE = 'tweenr', from, to, at, ease)
}

constant_at_interpolator <- function(from, to, at, ease) {
    .Call('_tweenr_constant_at_interpolator', PACKAGE = 'tweenr', from, to, at, ease)
}

list_at_interpolator <- function(from, to, at, ease) {
    .Call('_tweenr_list_at_interpolator', PACKAGE = 'tweenr', from, to, at, ease)
}

numlist_at_interpolator <- function(from, to, at, ease) {
    .Call('_tweenr_numlist_at_interpolator', PACKAGE = 'tweenr', from, to, at, ease)
}

numeric_fill_interpolator <- function(data, ease) {
    .Call('_tweenr_numeric_fill_interpolator', PACKAGE = 'tweenr', data, ease)
}

colour_fill_interpolator <- function(data, ease) {
    .Call('_tweenr_colour_fill_interpolator', PACKAGE = 'tweenr', data, ease)
}

constant_fill_interpolator <- function(data, ease) {
    .Call('_tweenr_constant_fill_interpolator', PACKAGE = 'tweenr', data, ease)
}

list_fill_interpolator <- function(data, ease) {
    .Call('_tweenr_list_fill_interpolator', PACKAGE = 'tweenr', data, ease)
}

numlist_fill_interpolator <- function(data, ease) {
    .Call('_tweenr_numlist_fill_interpolator', PACKAGE = 'tweenr', data, ease)
}

