# Generated by cpp11: do not edit by hand

numeric_along_interpolator <- function(data, group, time, history, keep_last, frames, ease) {
  .Call(`_tweenr_numeric_along_interpolator`, data, group, time, history, keep_last, frames, ease)
}

colour_along_interpolator <- function(data, group, time, history, keep_last, frames, ease) {
  .Call(`_tweenr_colour_along_interpolator`, data, group, time, history, keep_last, frames, ease)
}

constant_along_interpolator <- function(data, group, time, history, keep_last, frames, ease) {
  .Call(`_tweenr_constant_along_interpolator`, data, group, time, history, keep_last, frames, ease)
}

list_along_interpolator <- function(data, group, time, history, keep_last, frames, ease) {
  .Call(`_tweenr_list_along_interpolator`, data, group, time, history, keep_last, frames, ease)
}

numlist_along_interpolator <- function(data, group, time, history, keep_last, frames, ease) {
  .Call(`_tweenr_numlist_along_interpolator`, data, group, time, history, keep_last, frames, ease)
}

phase_along_interpolator <- function(group, time, history, keep_last, frames) {
  .Call(`_tweenr_phase_along_interpolator`, group, time, history, keep_last, frames)
}

numeric_at_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_numeric_at_interpolator`, from, to, at, ease)
}

colour_at_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_colour_at_interpolator`, from, to, at, ease)
}

constant_at_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_constant_at_interpolator`, from, to, at, ease)
}

list_at_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_list_at_interpolator`, from, to, at, ease)
}

numlist_at_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_numlist_at_interpolator`, from, to, at, ease)
}

numeric_at_t_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_numeric_at_t_interpolator`, from, to, at, ease)
}

colour_at_t_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_colour_at_t_interpolator`, from, to, at, ease)
}

constant_at_t_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_constant_at_t_interpolator`, from, to, at, ease)
}

list_at_t_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_list_at_t_interpolator`, from, to, at, ease)
}

numlist_at_t_interpolator <- function(from, to, at, ease) {
  .Call(`_tweenr_numlist_at_t_interpolator`, from, to, at, ease)
}

numeric_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_numeric_element_interpolator`, data, group, frame, ease)
}

colour_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_colour_element_interpolator`, data, group, frame, ease)
}

constant_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_constant_element_interpolator`, data, group, frame, ease)
}

list_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_list_element_interpolator`, data, group, frame, ease)
}

numlist_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_numlist_element_interpolator`, data, group, frame, ease)
}

phase_element_interpolator <- function(data, group, frame, ease) {
  .Call(`_tweenr_phase_element_interpolator`, data, group, frame, ease)
}

numeric_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_numeric_element_at_interpolator`, data, group, time, at, ease)
}

colour_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_colour_element_at_interpolator`, data, group, time, at, ease)
}

constant_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_constant_element_at_interpolator`, data, group, time, at, ease)
}

list_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_list_element_at_interpolator`, data, group, time, at, ease)
}

numlist_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_numlist_element_at_interpolator`, data, group, time, at, ease)
}

phase_element_at_interpolator <- function(data, group, time, at, ease) {
  .Call(`_tweenr_phase_element_at_interpolator`, data, group, time, at, ease)
}

numeric_fill_interpolator <- function(data, ease) {
  .Call(`_tweenr_numeric_fill_interpolator`, data, ease)
}

colour_fill_interpolator <- function(data, ease) {
  .Call(`_tweenr_colour_fill_interpolator`, data, ease)
}

constant_fill_interpolator <- function(data, ease) {
  .Call(`_tweenr_constant_fill_interpolator`, data, ease)
}

list_fill_interpolator <- function(data, ease) {
  .Call(`_tweenr_list_fill_interpolator`, data, ease)
}

numlist_fill_interpolator <- function(data, ease) {
  .Call(`_tweenr_numlist_fill_interpolator`, data, ease)
}

numeric_state_interpolator <- function(data, states) {
  .Call(`_tweenr_numeric_state_interpolator`, data, states)
}

colour_state_interpolator <- function(data, states) {
  .Call(`_tweenr_colour_state_interpolator`, data, states)
}

constant_state_interpolator <- function(data, states) {
  .Call(`_tweenr_constant_state_interpolator`, data, states)
}

list_state_interpolator <- function(data, states) {
  .Call(`_tweenr_list_state_interpolator`, data, states)
}

numlist_state_interpolator <- function(data, states) {
  .Call(`_tweenr_numlist_state_interpolator`, data, states)
}

phase_state_interpolator <- function(data, states) {
  .Call(`_tweenr_phase_state_interpolator`, data, states)
}
